@@ -38,6 +38,7 @@ var hierarchy =
     ] ],
     [ "libcamera::CameraSensorProperties", "structlibcamera_1_1CameraSensorProperties.html", null ],
     [ "libcamera::DebayerParams::CcmColumn", "structlibcamera_1_1DebayerParams_1_1CcmColumn.html", null ],
+    [ "libcamera::ClockRecovery", "classlibcamera_1_1ClockRecovery.html", null ],
     [ "libcamera::ColorSpace", "classlibcamera_1_1ColorSpace.html", null ],
     [ "libcamera::ConditionVariable", "classlibcamera_1_1ConditionVariable.html", null ],
     [ "libcamera::ControlId", "classlibcamera_1_1ControlId.html", [
@@ -62,7 +63,6 @@ var hierarchy =
     ] ],
     [ "libcamera::DebayerParams", "structlibcamera_1_1DebayerParams.html", null ],
     [ "libcamera::DebugMetadata", "classlibcamera_1_1DebugMetadata.html", null ],
-    [ "libcamera::DelayedControls", "classlibcamera_1_1DelayedControls.html", null ],
     [ "libcamera::DeviceEnumerator", "classlibcamera_1_1DeviceEnumerator.html", null ],
     [ "libcamera::DeviceMatch", "classlibcamera_1_1DeviceMatch.html", null ],
     [ "libcamera::DmaBufAllocator", "classlibcamera_1_1DmaBufAllocator.html", null ],
@@ -162,6 +162,7 @@ var hierarchy =
       [ "libcamera::Camera", "classlibcamera_1_1Camera.html", null ],
       [ "libcamera::CameraManager", "classlibcamera_1_1CameraManager.html", null ],
       [ "libcamera::DebayerCpu", "classlibcamera_1_1DebayerCpu.html", null ],
+      [ "libcamera::DelayedControls", "classlibcamera_1_1DelayedControls.html", null ],
       [ "libcamera::EventNotifier", "classlibcamera_1_1EventNotifier.html", null ],
       [ "libcamera::PipelineHandler", "classlibcamera_1_1PipelineHandler.html", null ],
       [ "libcamera::SoftwareIsp", "classlibcamera_1_1SoftwareIsp.html", null ],
@@ -184,7 +185,6 @@ var hierarchy =
       [ "libcamera::Request::Private", "classlibcamera_1_1Request_1_1Private.html", null ]
     ] ],
     [ "libcamera::Process", "classlibcamera_1_1Process.html", null ],
-    [ "libcamera::ProcessManager", "classlibcamera_1_1ProcessManager.html", null ],
     [ "libcamera::PubKey", "classlibcamera_1_1PubKey.html", null ],
     [ "libcamera::ipa::Pwl", "classlibcamera_1_1ipa_1_1Pwl.html", null ],
     [ "libcamera::Rectangle", "classlibcamera_1_1Rectangle.html", null ],
