@@ -15,6 +15,7 @@ var namespacelibcamera =
     [ "CameraSensorFactory", "classlibcamera_1_1CameraSensorFactory.html", "classlibcamera_1_1CameraSensorFactory" ],
     [ "CameraSensorFactoryBase", "classlibcamera_1_1CameraSensorFactoryBase.html", "classlibcamera_1_1CameraSensorFactoryBase" ],
     [ "CameraSensorProperties", "structlibcamera_1_1CameraSensorProperties.html", "structlibcamera_1_1CameraSensorProperties" ],
+    [ "ClockRecovery", "classlibcamera_1_1ClockRecovery.html", "classlibcamera_1_1ClockRecovery" ],
     [ "ColorSpace", "classlibcamera_1_1ColorSpace.html", "classlibcamera_1_1ColorSpace" ],
     [ "ConditionVariable", "classlibcamera_1_1ConditionVariable.html", null ],
     [ "Control", "classlibcamera_1_1Control.html", "classlibcamera_1_1Control" ],
@@ -92,7 +93,6 @@ var namespacelibcamera =
     [ "PixelFormatInfo", "classlibcamera_1_1PixelFormatInfo.html", "classlibcamera_1_1PixelFormatInfo" ],
     [ "Point", "classlibcamera_1_1Point.html", "classlibcamera_1_1Point" ],
     [ "Process", "classlibcamera_1_1Process.html", "classlibcamera_1_1Process" ],
-    [ "ProcessManager", "classlibcamera_1_1ProcessManager.html", "classlibcamera_1_1ProcessManager" ],
     [ "PubKey", "classlibcamera_1_1PubKey.html", "classlibcamera_1_1PubKey" ],
     [ "Rectangle", "classlibcamera_1_1Rectangle.html", "classlibcamera_1_1Rectangle" ],
     [ "Request", "classlibcamera_1_1Request.html", "classlibcamera_1_1Request" ],
@@ -198,7 +198,7 @@ var namespacelibcamera =
       [ "Rot90", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571ad5251a97af7b4036b4528a54405ea2ad", null ],
       [ "Rot180Transpose", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571adaa7494d424939ff93c1c9396b065732", null ]
     ] ],
-    [ "_log", "namespacelibcamera.html#a1921244466953ec1310eb4194d6dcc1a", null ],
+    [ "_log", "namespacelibcamera.html#a4d4c3ef21c98fab4eb53d7bcc4779e24", null ],
     [ "ipaCreate", "namespacelibcamera.html#af40a632a4025a789df881469fe54e681", null ],
     [ "logSetFile", "namespacelibcamera.html#a4fb1124bbbee917f5a29dbe79930f884", null ],
     [ "logSetLevel", "namespacelibcamera.html#a1818bc26a0478a661f39f0a54f4894a4", null ],
