@@ -78,21 +78,22 @@ var NAVTREEINDEX =
 [
 "af_8h.html",
 "classlibcamera_1_1CameraManager.html",
-"classlibcamera_1_1ControlList.html#a39120e9db432c3abfd95a8615e2a3981",
-"classlibcamera_1_1DeviceEnumerator.html#a3c539b6b75170fcf224ed5574c971842",
-"classlibcamera_1_1FrameBufferAllocator.html",
-"classlibcamera_1_1Matrix.html#a8dab36799da41b19dbb85c4c3469b171",
-"classlibcamera_1_1PipelineHandler.html#a6f7d619636c8988aeed3afd43ce8ed02",
-"classlibcamera_1_1Request_1_1Private.html#a6d334bff3c7a4d007c94a5f08310e0a5",
-"classlibcamera_1_1Stream.html#ae8b733271e2cb86da5acd9c8797ecf12",
-"classlibcamera_1_1V4L2Subdevice.html#a62c91acb30f22a4b526b157c03d2cc60",
-"classlibcamera_1_1ipa_1_1AwbAlgorithm.html",
-"debayer_8h_source.html",
-"namespacelibcamera.html#a40a8adae6eaa668ac965dc350ca2b295",
-"namespacelibcamera_1_1controls.html#aff89777acbe21fd9fb4ada07efc61e37",
-"structlibcamera_1_1IPABuffer.html#a95ec7586dc1c7060228423f182329ca6",
-"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a331b6f919b1ab5f928264cc026ae8791"
+"classlibcamera_1_1ControlInfoMap.html#ada413b315b66e5dbebeb1e66763b043f",
+"classlibcamera_1_1DelayedControls.html#a6e4ac7f9c74b6f62d4c47f0e455ba84c",
+"classlibcamera_1_1FrameBuffer.html#a4cd8c7f94d994ec9015a0e21720593c4",
+"classlibcamera_1_1MappedFrameBuffer.html#a656d42eef1b5847073197a58cf860bf2",
+"classlibcamera_1_1PipelineHandler.html#a25b18b2f7a20e726485880cae509204d",
+"classlibcamera_1_1Request.html#aeb951e740b488f282292519625025491",
+"classlibcamera_1_1SoftwareIsp.html#af9b9eeb091be51db551189b3c6107201",
+"classlibcamera_1_1V4L2Subdevice.html#a3fe6c59c0322a3319068b52effc2162e",
+"classlibcamera_1_1ipa_1_1Algorithm.html#adb5e02af3c5966e4ceaaacf9c48c2a3b",
+"control__serializer_8h_source.html",
+"namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571a0b5d83f7ecb707aee4151b6575ca5af7",
+"namespacelibcamera_1_1controls.html#ae9d097adf411aec39aca730f515e107d",
+"structlibcamera_1_1FrameMetadata.html#a7ef385a14be5e162e9f7d66ce1152c8c",
+"structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinear.html#ab6f5bdad5b0eadf69672f28a350d4206"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronization';
-var SYNCOFFMSG = 'click to enable panel synchronization';
\ No newline at end of file
+var SYNCOFFMSG = 'click to enable panel synchronization';
+var LISTOFALLMEMBERS = 'List of all members';
\ No newline at end of file
