@@ -1,6 +1,19 @@
 var NAVTREEINDEX13 =
 {
-"namespacelibcamera_1_1controls.html#aff89777acbe21fd9fb4ada07efc61e37":[6,0,0,0,101],
+"namespacelibcamera_1_1controls.html#ae9d097adf411aec39aca730f515e107d":[6,0,0,0,60],
+"namespacelibcamera_1_1controls.html#aec6eb380687d3d4f46a2d32dd30855fa":[6,0,0,0,10],
+"namespacelibcamera_1_1controls.html#aec6eb380687d3d4f46a2d32dd30855faa30bb45e53a6fdfe537add00658f43137":[6,0,0,0,10,1],
+"namespacelibcamera_1_1controls.html#aec6eb380687d3d4f46a2d32dd30855faa64efb4d4f903ea23042dcbea2b3f90e1":[6,0,0,0,10,2],
+"namespacelibcamera_1_1controls.html#aec6eb380687d3d4f46a2d32dd30855faac3fcb5d9a1f7b901b51bf19362acc4a4":[6,0,0,0,10,0],
+"namespacelibcamera_1_1controls.html#aedf6ad40f5ae4ea338a49712e1cdfcaa":[6,0,0,0,76],
+"namespacelibcamera_1_1controls.html#aef08464a29a22b97092d6345ffc7ebc8":[6,0,0,0,92],
+"namespacelibcamera_1_1controls.html#af0057ec539680c4c2b48ffb51842977d":[6,0,0,0,4],
+"namespacelibcamera_1_1controls.html#af0057ec539680c4c2b48ffb51842977da6d9f9b8eaf7b700db769182a35f28cca":[6,0,0,0,4,2],
+"namespacelibcamera_1_1controls.html#af0057ec539680c4c2b48ffb51842977da992740e17e32bc905044d072d88197c5":[6,0,0,0,4,0],
+"namespacelibcamera_1_1controls.html#af0057ec539680c4c2b48ffb51842977daf1d9e674a9eddaa5ec6869c76a9fff52":[6,0,0,0,4,1],
+"namespacelibcamera_1_1controls.html#af406d4a9a43f1c5b4c1c4e38026468d1":[6,0,0,0,71],
+"namespacelibcamera_1_1controls.html#af8419d5eeb8689f5c27725b63d468ef2":[6,0,0,0,73],
+"namespacelibcamera_1_1controls.html#aff89777acbe21fd9fb4ada07efc61e37":[6,0,0,0,102],
 "namespacelibcamera_1_1controls_1_1debug.html":[6,0,0,0,0],
 "namespacelibcamera_1_1controls_1_1draft.html":[6,0,0,0,1],
 "namespacelibcamera_1_1controls_1_1draft.html#a001dd6c5c5f7b0620932ae874df94b22":[6,0,0,0,1,27],
@@ -131,18 +144,18 @@ var NAVTREEINDEX13 =
 "orientation_8h.html":[8,0,1,0,12],
 "orientation_8h_source.html":[8,0,1,0,12],
 "pages.html":[],
-"pipeline__handler_8h.html":[8,0,1,0,1,30],
-"pipeline__handler_8h.html#a8dae35473d8718ef287a93c2092c47bb":[8,0,1,0,1,30,3],
-"pipeline__handler_8h_source.html":[8,0,1,0,1,30],
+"pipeline__handler_8h.html":[8,0,1,0,1,31],
+"pipeline__handler_8h.html#a8dae35473d8718ef287a93c2092c47bb":[8,0,1,0,1,31,3],
+"pipeline__handler_8h_source.html":[8,0,1,0,1,31],
 "pixel__format_8h.html":[8,0,1,0,13],
 "pixel__format_8h_source.html":[8,0,1,0,13],
 "private_8h_source.html":[8,0,1,0,0,13],
-"process_8h.html":[8,0,1,0,1,31],
-"process_8h_source.html":[8,0,1,0,1,31],
+"process_8h.html":[8,0,1,0,1,32],
+"process_8h_source.html":[8,0,1,0,1,32],
 "property__ids_8h.html":[8,0,0,0,0,4],
 "property__ids_8h_source.html":[8,0,0,0,0,4],
-"pub__key_8h.html":[8,0,1,0,1,32],
-"pub__key_8h_source.html":[8,0,1,0,1,32],
+"pub__key_8h.html":[8,0,1,0,1,33],
+"pub__key_8h_source.html":[8,0,1,0,1,33],
 "pwl_8h.html":[8,0,2,0,1,15],
 "pwl_8h_source.html":[8,0,2,0,1,15],
 "request_8h.html":[8,0,1,0,14],
@@ -152,13 +165,13 @@ var NAVTREEINDEX13 =
 "shared__fd_8h.html":[8,0,1,0,0,15],
 "shared__fd_8h_source.html":[8,0,1,0,0,15],
 "shared__mem__object_8cpp.html":[8,0,2,1,2],
-"shared__mem__object_8h_source.html":[8,0,1,0,1,34],
+"shared__mem__object_8h_source.html":[8,0,1,0,1,35],
 "signal_8h.html":[8,0,1,0,0,16],
 "signal_8h_source.html":[8,0,1,0,0,16],
 "software__isp_8cpp.html":[8,0,2,1,0,2],
 "software__isp_8h_source.html":[8,0,1,0,1,1,1],
-"source__paths_8h.html":[8,0,1,0,1,35],
-"source__paths_8h_source.html":[8,0,1,0,1,35],
+"source__paths_8h.html":[8,0,1,0,1,36],
+"source__paths_8h_source.html":[8,0,1,0,1,36],
 "stream_8h.html":[8,0,1,0,15],
 "stream_8h_source.html":[8,0,1,0,15],
 "structlibcamera_1_1CameraSensorProperties.html":[6,0,0,14],
@@ -179,75 +192,62 @@ var NAVTREEINDEX13 =
 "structlibcamera_1_1CameraSensorProperties_1_1SensorDelays.html#ae737f9055a75cb63e674946112bf6afb":[7,0,0,13,0,1],
 "structlibcamera_1_1CameraSensorProperties_1_1SensorDelays.html#afda596fdd9ce35d63c127c5b32be4ad5":[6,0,0,14,0,2],
 "structlibcamera_1_1CameraSensorProperties_1_1SensorDelays.html#afda596fdd9ce35d63c127c5b32be4ad5":[7,0,0,13,0,2],
-"structlibcamera_1_1DebayerParams.html":[6,0,0,30],
-"structlibcamera_1_1DebayerParams.html":[7,0,0,29],
-"structlibcamera_1_1DebayerParams.html#a00776505d60db14260f2290b87e64eec":[6,0,0,30,7],
-"structlibcamera_1_1DebayerParams.html#a00776505d60db14260f2290b87e64eec":[7,0,0,29,7],
-"structlibcamera_1_1DebayerParams.html#a0111b2ccaa61e1f5e19095a752a8a5c0":[6,0,0,30,3],
-"structlibcamera_1_1DebayerParams.html#a0111b2ccaa61e1f5e19095a752a8a5c0":[7,0,0,29,3],
-"structlibcamera_1_1DebayerParams.html#a37a376cee1336a2319f01a36a6d6c416":[6,0,0,30,5],
-"structlibcamera_1_1DebayerParams.html#a37a376cee1336a2319f01a36a6d6c416":[7,0,0,29,5],
-"structlibcamera_1_1DebayerParams.html#a43c9fda4ee662eb7928691b573003607":[6,0,0,30,9],
-"structlibcamera_1_1DebayerParams.html#a43c9fda4ee662eb7928691b573003607":[7,0,0,29,9],
-"structlibcamera_1_1DebayerParams.html#a542e7943da8b064871868dc4caeaea5d":[6,0,0,30,1],
-"structlibcamera_1_1DebayerParams.html#a542e7943da8b064871868dc4caeaea5d":[7,0,0,29,1],
-"structlibcamera_1_1DebayerParams.html#a7067e64c2b77c1eff1854cf28d4009d2":[6,0,0,30,4],
-"structlibcamera_1_1DebayerParams.html#a7067e64c2b77c1eff1854cf28d4009d2":[7,0,0,29,4],
-"structlibcamera_1_1DebayerParams.html#ac757f4b1fe6af9391e9afcbbaa32d914":[6,0,0,30,8],
-"structlibcamera_1_1DebayerParams.html#ac757f4b1fe6af9391e9afcbbaa32d914":[7,0,0,29,8],
-"structlibcamera_1_1DebayerParams.html#ad0c1b37119210a52dae5cc6aa2ac6f6d":[6,0,0,30,2],
-"structlibcamera_1_1DebayerParams.html#ad0c1b37119210a52dae5cc6aa2ac6f6d":[7,0,0,29,2],
-"structlibcamera_1_1DebayerParams.html#aee8b56499d142b91d92024e92a9710f5":[6,0,0,30,6],
-"structlibcamera_1_1DebayerParams.html#aee8b56499d142b91d92024e92a9710f5":[7,0,0,29,6],
-"structlibcamera_1_1DebayerParams_1_1CcmColumn.html":[6,0,0,30,0],
-"structlibcamera_1_1DebayerParams_1_1CcmColumn.html":[7,0,0,29,0],
-"structlibcamera_1_1DebayerParams_1_1CcmColumn.html#a0bf5cd03cd38b5b8a21edc450e3ab2ce":[6,0,0,30,0,0],
-"structlibcamera_1_1DebayerParams_1_1CcmColumn.html#a0bf5cd03cd38b5b8a21edc450e3ab2ce":[7,0,0,29,0,0],
-"structlibcamera_1_1DebayerParams_1_1CcmColumn.html#a3babc51dfd300088dc6995d01a44476b":[6,0,0,30,0,2],
-"structlibcamera_1_1DebayerParams_1_1CcmColumn.html#a3babc51dfd300088dc6995d01a44476b":[7,0,0,29,0,2],
-"structlibcamera_1_1DebayerParams_1_1CcmColumn.html#acb30f008a9315c198d6ebc60ded58fbd":[6,0,0,30,0,1],
-"structlibcamera_1_1DebayerParams_1_1CcmColumn.html#acb30f008a9315c198d6ebc60ded58fbd":[7,0,0,29,0,1],
-"structlibcamera_1_1DelayedControls_1_1ControlParams.html":[6,0,0,32,0],
-"structlibcamera_1_1DelayedControls_1_1ControlParams.html":[7,0,0,31,0],
-"structlibcamera_1_1DelayedControls_1_1ControlParams.html#ab6a4c4f8d27d7125f8c1a750f79f740c":[6,0,0,32,0,0],
-"structlibcamera_1_1DelayedControls_1_1ControlParams.html#ab6a4c4f8d27d7125f8c1a750f79f740c":[7,0,0,31,0,0],
-"structlibcamera_1_1DelayedControls_1_1ControlParams.html#afca69ac04777f136e1cc347fcb7d26eb":[6,0,0,32,0,1],
-"structlibcamera_1_1DelayedControls_1_1ControlParams.html#afca69ac04777f136e1cc347fcb7d26eb":[7,0,0,31,0,1],
-"structlibcamera_1_1FrameBuffer_1_1Plane.html":[6,0,0,44,0],
-"structlibcamera_1_1FrameBuffer_1_1Plane.html":[7,0,0,43,0],
-"structlibcamera_1_1FrameBuffer_1_1Plane.html#a40d0a05cfdf5571938ea144acb5cc7f7":[6,0,0,44,0,0],
-"structlibcamera_1_1FrameBuffer_1_1Plane.html#a40d0a05cfdf5571938ea144acb5cc7f7":[7,0,0,43,0,0],
-"structlibcamera_1_1FrameBuffer_1_1Plane.html#a610e272235bf4dbcb6b147623212ecf7":[6,0,0,44,0,1],
-"structlibcamera_1_1FrameBuffer_1_1Plane.html#a610e272235bf4dbcb6b147623212ecf7":[7,0,0,43,0,1],
-"structlibcamera_1_1FrameBuffer_1_1Plane.html#ae6caf23c19a84ee28668ac7c5b37eda8":[6,0,0,44,0,2],
-"structlibcamera_1_1FrameBuffer_1_1Plane.html#ae6caf23c19a84ee28668ac7c5b37eda8":[7,0,0,43,0,2],
-"structlibcamera_1_1FrameMetadata.html":[6,0,0,46],
-"structlibcamera_1_1FrameMetadata.html":[7,0,0,45],
-"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846":[6,0,0,46,1],
-"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846":[7,0,0,45,1],
-"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a64dc568d79ee70881b81b1a60ce65a46":[6,0,0,46,1,2],
-"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a64dc568d79ee70881b81b1a60ce65a46":[7,0,0,45,1,2],
-"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a98a0ed2652556a3108128fd4e4b27611":[6,0,0,46,1,0],
-"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a98a0ed2652556a3108128fd4e4b27611":[7,0,0,45,1,0],
-"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846abc47f513b7d307d6b30038c80d999c65":[6,0,0,46,1,1],
-"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846abc47f513b7d307d6b30038c80d999c65":[7,0,0,45,1,1],
-"structlibcamera_1_1FrameMetadata.html#a11029c4b81f5d8f8c226b7e68256bce9":[6,0,0,46,3],
-"structlibcamera_1_1FrameMetadata.html#a11029c4b81f5d8f8c226b7e68256bce9":[7,0,0,45,3],
-"structlibcamera_1_1FrameMetadata.html#a4777e2fcb219835fc4ae2d67d028e59a":[6,0,0,46,5],
-"structlibcamera_1_1FrameMetadata.html#a4777e2fcb219835fc4ae2d67d028e59a":[7,0,0,45,5],
-"structlibcamera_1_1FrameMetadata.html#a7ef385a14be5e162e9f7d66ce1152c8c":[6,0,0,46,4],
-"structlibcamera_1_1FrameMetadata.html#a7ef385a14be5e162e9f7d66ce1152c8c":[7,0,0,45,4],
-"structlibcamera_1_1FrameMetadata.html#a8aebeef9d92bc14671510f09dbcc0377":[6,0,0,46,2],
-"structlibcamera_1_1FrameMetadata.html#a8aebeef9d92bc14671510f09dbcc0377":[7,0,0,45,2],
-"structlibcamera_1_1FrameMetadata.html#aefd4807e5a7d1f17034c34ffa2e5813b":[6,0,0,46,6],
-"structlibcamera_1_1FrameMetadata.html#aefd4807e5a7d1f17034c34ffa2e5813b":[7,0,0,45,6],
-"structlibcamera_1_1FrameMetadata_1_1Plane.html":[6,0,0,46,0],
-"structlibcamera_1_1FrameMetadata_1_1Plane.html":[7,0,0,45,0],
-"structlibcamera_1_1FrameMetadata_1_1Plane.html#a4537c0ebf8254ab70a4f410ca75e401b":[6,0,0,46,0,0],
-"structlibcamera_1_1FrameMetadata_1_1Plane.html#a4537c0ebf8254ab70a4f410ca75e401b":[7,0,0,45,0,0],
-"structlibcamera_1_1IPABuffer.html":[6,0,0,51],
-"structlibcamera_1_1IPABuffer.html":[7,0,0,50],
-"structlibcamera_1_1IPABuffer.html#a256847bdaa0df391855638eef7b027b5":[6,0,0,51,1],
-"structlibcamera_1_1IPABuffer.html#a256847bdaa0df391855638eef7b027b5":[7,0,0,50,1],
-"structlibcamera_1_1IPABuffer.html#a95ec7586dc1c7060228423f182329ca6":[6,0,0,51,0]
+"structlibcamera_1_1DebayerParams.html":[6,0,0,31],
+"structlibcamera_1_1DebayerParams.html":[7,0,0,30],
+"structlibcamera_1_1DebayerParams.html#a00776505d60db14260f2290b87e64eec":[6,0,0,31,7],
+"structlibcamera_1_1DebayerParams.html#a00776505d60db14260f2290b87e64eec":[7,0,0,30,7],
+"structlibcamera_1_1DebayerParams.html#a0111b2ccaa61e1f5e19095a752a8a5c0":[6,0,0,31,3],
+"structlibcamera_1_1DebayerParams.html#a0111b2ccaa61e1f5e19095a752a8a5c0":[7,0,0,30,3],
+"structlibcamera_1_1DebayerParams.html#a37a376cee1336a2319f01a36a6d6c416":[6,0,0,31,5],
+"structlibcamera_1_1DebayerParams.html#a37a376cee1336a2319f01a36a6d6c416":[7,0,0,30,5],
+"structlibcamera_1_1DebayerParams.html#a43c9fda4ee662eb7928691b573003607":[6,0,0,31,9],
+"structlibcamera_1_1DebayerParams.html#a43c9fda4ee662eb7928691b573003607":[7,0,0,30,9],
+"structlibcamera_1_1DebayerParams.html#a542e7943da8b064871868dc4caeaea5d":[6,0,0,31,1],
+"structlibcamera_1_1DebayerParams.html#a542e7943da8b064871868dc4caeaea5d":[7,0,0,30,1],
+"structlibcamera_1_1DebayerParams.html#a7067e64c2b77c1eff1854cf28d4009d2":[6,0,0,31,4],
+"structlibcamera_1_1DebayerParams.html#a7067e64c2b77c1eff1854cf28d4009d2":[7,0,0,30,4],
+"structlibcamera_1_1DebayerParams.html#ac757f4b1fe6af9391e9afcbbaa32d914":[6,0,0,31,8],
+"structlibcamera_1_1DebayerParams.html#ac757f4b1fe6af9391e9afcbbaa32d914":[7,0,0,30,8],
+"structlibcamera_1_1DebayerParams.html#ad0c1b37119210a52dae5cc6aa2ac6f6d":[6,0,0,31,2],
+"structlibcamera_1_1DebayerParams.html#ad0c1b37119210a52dae5cc6aa2ac6f6d":[7,0,0,30,2],
+"structlibcamera_1_1DebayerParams.html#aee8b56499d142b91d92024e92a9710f5":[6,0,0,31,6],
+"structlibcamera_1_1DebayerParams.html#aee8b56499d142b91d92024e92a9710f5":[7,0,0,30,6],
+"structlibcamera_1_1DebayerParams_1_1CcmColumn.html":[6,0,0,31,0],
+"structlibcamera_1_1DebayerParams_1_1CcmColumn.html":[7,0,0,30,0],
+"structlibcamera_1_1DebayerParams_1_1CcmColumn.html#a0bf5cd03cd38b5b8a21edc450e3ab2ce":[6,0,0,31,0,0],
+"structlibcamera_1_1DebayerParams_1_1CcmColumn.html#a0bf5cd03cd38b5b8a21edc450e3ab2ce":[7,0,0,30,0,0],
+"structlibcamera_1_1DebayerParams_1_1CcmColumn.html#a3babc51dfd300088dc6995d01a44476b":[6,0,0,31,0,2],
+"structlibcamera_1_1DebayerParams_1_1CcmColumn.html#a3babc51dfd300088dc6995d01a44476b":[7,0,0,30,0,2],
+"structlibcamera_1_1DebayerParams_1_1CcmColumn.html#acb30f008a9315c198d6ebc60ded58fbd":[6,0,0,31,0,1],
+"structlibcamera_1_1DebayerParams_1_1CcmColumn.html#acb30f008a9315c198d6ebc60ded58fbd":[7,0,0,30,0,1],
+"structlibcamera_1_1DelayedControls_1_1ControlParams.html":[6,0,0,33,0],
+"structlibcamera_1_1DelayedControls_1_1ControlParams.html":[7,0,0,32,0],
+"structlibcamera_1_1DelayedControls_1_1ControlParams.html#ab6a4c4f8d27d7125f8c1a750f79f740c":[6,0,0,33,0,0],
+"structlibcamera_1_1DelayedControls_1_1ControlParams.html#ab6a4c4f8d27d7125f8c1a750f79f740c":[7,0,0,32,0,0],
+"structlibcamera_1_1DelayedControls_1_1ControlParams.html#afca69ac04777f136e1cc347fcb7d26eb":[6,0,0,33,0,1],
+"structlibcamera_1_1DelayedControls_1_1ControlParams.html#afca69ac04777f136e1cc347fcb7d26eb":[7,0,0,32,0,1],
+"structlibcamera_1_1FrameBuffer_1_1Plane.html":[6,0,0,45,0],
+"structlibcamera_1_1FrameBuffer_1_1Plane.html":[7,0,0,44,0],
+"structlibcamera_1_1FrameBuffer_1_1Plane.html#a40d0a05cfdf5571938ea144acb5cc7f7":[6,0,0,45,0,0],
+"structlibcamera_1_1FrameBuffer_1_1Plane.html#a40d0a05cfdf5571938ea144acb5cc7f7":[7,0,0,44,0,0],
+"structlibcamera_1_1FrameBuffer_1_1Plane.html#a610e272235bf4dbcb6b147623212ecf7":[6,0,0,45,0,1],
+"structlibcamera_1_1FrameBuffer_1_1Plane.html#a610e272235bf4dbcb6b147623212ecf7":[7,0,0,44,0,1],
+"structlibcamera_1_1FrameBuffer_1_1Plane.html#ae6caf23c19a84ee28668ac7c5b37eda8":[6,0,0,45,0,2],
+"structlibcamera_1_1FrameBuffer_1_1Plane.html#ae6caf23c19a84ee28668ac7c5b37eda8":[7,0,0,44,0,2],
+"structlibcamera_1_1FrameMetadata.html":[6,0,0,47],
+"structlibcamera_1_1FrameMetadata.html":[7,0,0,46],
+"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846":[6,0,0,47,1],
+"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846":[7,0,0,46,1],
+"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a64dc568d79ee70881b81b1a60ce65a46":[6,0,0,47,1,2],
+"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a64dc568d79ee70881b81b1a60ce65a46":[7,0,0,46,1,2],
+"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a6bca45b4e601631b9ef74de1d574634e":[6,0,0,47,1,3],
+"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a6bca45b4e601631b9ef74de1d574634e":[7,0,0,46,1,3],
+"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a98a0ed2652556a3108128fd4e4b27611":[6,0,0,47,1,0],
+"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a98a0ed2652556a3108128fd4e4b27611":[7,0,0,46,1,0],
+"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846abc47f513b7d307d6b30038c80d999c65":[6,0,0,47,1,1],
+"structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846abc47f513b7d307d6b30038c80d999c65":[7,0,0,46,1,1],
+"structlibcamera_1_1FrameMetadata.html#a11029c4b81f5d8f8c226b7e68256bce9":[6,0,0,47,3],
+"structlibcamera_1_1FrameMetadata.html#a11029c4b81f5d8f8c226b7e68256bce9":[7,0,0,46,3],
+"structlibcamera_1_1FrameMetadata.html#a4777e2fcb219835fc4ae2d67d028e59a":[6,0,0,47,5],
+"structlibcamera_1_1FrameMetadata.html#a4777e2fcb219835fc4ae2d67d028e59a":[7,0,0,46,5]
 };
