@@ -1,70 +1,85 @@
 var NAVTREEINDEX14 =
 {
-"structlibcamera_1_1IPABuffer.html#a95ec7586dc1c7060228423f182329ca6":[7,0,0,50,0],
-"structlibcamera_1_1IPACameraSensorInfo.html":[6,0,0,52],
-"structlibcamera_1_1IPACameraSensorInfo.html":[7,0,0,51],
-"structlibcamera_1_1IPACameraSensorInfo.html#a011900b9facd39607ad8d2e73cf2ec41":[6,0,0,52,10],
-"structlibcamera_1_1IPACameraSensorInfo.html#a011900b9facd39607ad8d2e73cf2ec41":[7,0,0,51,10],
-"structlibcamera_1_1IPACameraSensorInfo.html#a19967b85dd282779a331c126460d2ce8":[6,0,0,52,7],
-"structlibcamera_1_1IPACameraSensorInfo.html#a19967b85dd282779a331c126460d2ce8":[7,0,0,51,7],
-"structlibcamera_1_1IPACameraSensorInfo.html#a76f7926bb79f7f80781f67367ec4d13d":[6,0,0,52,3],
-"structlibcamera_1_1IPACameraSensorInfo.html#a76f7926bb79f7f80781f67367ec4d13d":[7,0,0,51,3],
-"structlibcamera_1_1IPACameraSensorInfo.html#a9bac676fe3ea200b18d42a3561c8a851":[6,0,0,52,8],
-"structlibcamera_1_1IPACameraSensorInfo.html#a9bac676fe3ea200b18d42a3561c8a851":[7,0,0,51,8],
-"structlibcamera_1_1IPACameraSensorInfo.html#aade1f3bd6e1d04666746d157382d6a23":[6,0,0,52,2],
-"structlibcamera_1_1IPACameraSensorInfo.html#aade1f3bd6e1d04666746d157382d6a23":[7,0,0,51,2],
-"structlibcamera_1_1IPACameraSensorInfo.html#ab0cf3b83926392c91fd167fedd035d89":[6,0,0,52,5],
-"structlibcamera_1_1IPACameraSensorInfo.html#ab0cf3b83926392c91fd167fedd035d89":[7,0,0,51,5],
-"structlibcamera_1_1IPACameraSensorInfo.html#ab9bcb46cefbc066407cc2b452968aeb4":[6,0,0,52,0],
-"structlibcamera_1_1IPACameraSensorInfo.html#ab9bcb46cefbc066407cc2b452968aeb4":[7,0,0,51,0],
-"structlibcamera_1_1IPACameraSensorInfo.html#ad02984d923b166afde48d66e4cec8738":[6,0,0,52,6],
-"structlibcamera_1_1IPACameraSensorInfo.html#ad02984d923b166afde48d66e4cec8738":[7,0,0,51,6],
-"structlibcamera_1_1IPACameraSensorInfo.html#adca663df67aa7c342ae826268ebd3f35":[6,0,0,52,1],
-"structlibcamera_1_1IPACameraSensorInfo.html#adca663df67aa7c342ae826268ebd3f35":[7,0,0,51,1],
-"structlibcamera_1_1IPACameraSensorInfo.html#ae4cde230536546acdd994a9648186222":[6,0,0,52,4],
-"structlibcamera_1_1IPACameraSensorInfo.html#ae4cde230536546acdd994a9648186222":[7,0,0,51,4],
-"structlibcamera_1_1IPACameraSensorInfo.html#afd51f1c6e93cafac4158655f0bfcdb48":[6,0,0,52,9],
-"structlibcamera_1_1IPACameraSensorInfo.html#afd51f1c6e93cafac4158655f0bfcdb48":[7,0,0,51,9],
-"structlibcamera_1_1IPAModuleInfo.html":[6,0,0,57],
-"structlibcamera_1_1IPAModuleInfo.html":[7,0,0,56],
-"structlibcamera_1_1IPAModuleInfo.html#a331a23c0af4e231386774d3669c2ae2b":[6,0,0,57,1],
-"structlibcamera_1_1IPAModuleInfo.html#a331a23c0af4e231386774d3669c2ae2b":[7,0,0,56,1],
-"structlibcamera_1_1IPAModuleInfo.html#a5112863521e069a2cea6ffa86f55cc57":[6,0,0,57,3],
-"structlibcamera_1_1IPAModuleInfo.html#a5112863521e069a2cea6ffa86f55cc57":[7,0,0,56,3],
-"structlibcamera_1_1IPAModuleInfo.html#ac33bfdafdebc4fce25b96a2508a9893e":[6,0,0,57,0],
-"structlibcamera_1_1IPAModuleInfo.html#ac33bfdafdebc4fce25b96a2508a9893e":[7,0,0,56,0],
-"structlibcamera_1_1IPAModuleInfo.html#afa7eac2cdc30d72d5d5002ebdafa44ab":[6,0,0,57,2],
-"structlibcamera_1_1IPAModuleInfo.html#afa7eac2cdc30d72d5d5002ebdafa44ab":[7,0,0,56,2],
-"structlibcamera_1_1IPASettings.html":[6,0,0,59],
-"structlibcamera_1_1IPASettings.html":[7,0,0,58],
-"structlibcamera_1_1IPASettings.html#a00504797aa18b72a4a33d2a3fcf45279":[6,0,0,59,1],
-"structlibcamera_1_1IPASettings.html#a00504797aa18b72a4a33d2a3fcf45279":[7,0,0,58,1],
-"structlibcamera_1_1IPASettings.html#a4a81359d9f743910b187bf90d9b5405d":[6,0,0,59,0],
-"structlibcamera_1_1IPASettings.html#a4a81359d9f743910b187bf90d9b5405d":[7,0,0,58,0],
-"structlibcamera_1_1IPAStream.html":[6,0,0,60],
-"structlibcamera_1_1IPAStream.html":[7,0,0,59],
-"structlibcamera_1_1IPAStream.html#a20526c2857a72c075d7c7529e104ca0d":[6,0,0,60,1],
-"structlibcamera_1_1IPAStream.html#a20526c2857a72c075d7c7529e104ca0d":[7,0,0,59,1],
-"structlibcamera_1_1IPAStream.html#ab8218f8e29722c3c7ec6af0acec81e34":[6,0,0,60,0],
-"structlibcamera_1_1IPAStream.html#ab8218f8e29722c3c7ec6af0acec81e34":[7,0,0,59,0],
-"structlibcamera_1_1IPCMessage_1_1Header.html":[6,0,0,61,0],
-"structlibcamera_1_1IPCMessage_1_1Header.html":[7,0,0,60,0],
-"structlibcamera_1_1IPCMessage_1_1Header.html#a1cabd51c87ac850dfbbf20bc5e2004c3":[6,0,0,61,0,1],
-"structlibcamera_1_1IPCMessage_1_1Header.html#a1cabd51c87ac850dfbbf20bc5e2004c3":[7,0,0,60,0,1],
-"structlibcamera_1_1IPCMessage_1_1Header.html#aa8309b06580e211a38336eec302ef130":[6,0,0,61,0,0],
-"structlibcamera_1_1IPCMessage_1_1Header.html#aa8309b06580e211a38336eec302ef130":[7,0,0,60,0,0],
-"structlibcamera_1_1IPCUnixSocket_1_1Payload.html":[6,0,0,63,0],
-"structlibcamera_1_1IPCUnixSocket_1_1Payload.html":[7,0,0,62,0],
-"structlibcamera_1_1IPCUnixSocket_1_1Payload.html#a8537c2639c9068d1ca6fa313ccee7530":[6,0,0,63,0,1],
-"structlibcamera_1_1IPCUnixSocket_1_1Payload.html#a8537c2639c9068d1ca6fa313ccee7530":[7,0,0,62,0,1],
-"structlibcamera_1_1IPCUnixSocket_1_1Payload.html#ab92d052b3f26d8fe481ad69003820943":[6,0,0,63,0,0],
-"structlibcamera_1_1IPCUnixSocket_1_1Payload.html#ab92d052b3f26d8fe481ad69003820943":[7,0,0,62,0,0],
-"structlibcamera_1_1PixelFormatInfo_1_1Plane.html":[6,0,0,89,0],
-"structlibcamera_1_1PixelFormatInfo_1_1Plane.html":[7,0,0,88,0],
-"structlibcamera_1_1PixelFormatInfo_1_1Plane.html#a718acb445ae5af9825489f728c78db9c":[6,0,0,89,0,1],
-"structlibcamera_1_1PixelFormatInfo_1_1Plane.html#a718acb445ae5af9825489f728c78db9c":[7,0,0,88,0,1],
-"structlibcamera_1_1PixelFormatInfo_1_1Plane.html#adceda8c9551a6d7475a0f1d31be97869":[6,0,0,89,0,0],
-"structlibcamera_1_1PixelFormatInfo_1_1Plane.html#adceda8c9551a6d7475a0f1d31be97869":[7,0,0,88,0,0],
+"structlibcamera_1_1FrameMetadata.html#a7ef385a14be5e162e9f7d66ce1152c8c":[6,0,0,47,4],
+"structlibcamera_1_1FrameMetadata.html#a7ef385a14be5e162e9f7d66ce1152c8c":[7,0,0,46,4],
+"structlibcamera_1_1FrameMetadata.html#a8aebeef9d92bc14671510f09dbcc0377":[6,0,0,47,2],
+"structlibcamera_1_1FrameMetadata.html#a8aebeef9d92bc14671510f09dbcc0377":[7,0,0,46,2],
+"structlibcamera_1_1FrameMetadata.html#aefd4807e5a7d1f17034c34ffa2e5813b":[6,0,0,47,6],
+"structlibcamera_1_1FrameMetadata.html#aefd4807e5a7d1f17034c34ffa2e5813b":[7,0,0,46,6],
+"structlibcamera_1_1FrameMetadata_1_1Plane.html":[6,0,0,47,0],
+"structlibcamera_1_1FrameMetadata_1_1Plane.html":[7,0,0,46,0],
+"structlibcamera_1_1FrameMetadata_1_1Plane.html#a4537c0ebf8254ab70a4f410ca75e401b":[6,0,0,47,0,0],
+"structlibcamera_1_1FrameMetadata_1_1Plane.html#a4537c0ebf8254ab70a4f410ca75e401b":[7,0,0,46,0,0],
+"structlibcamera_1_1IPABuffer.html":[6,0,0,52],
+"structlibcamera_1_1IPABuffer.html":[7,0,0,51],
+"structlibcamera_1_1IPABuffer.html#a256847bdaa0df391855638eef7b027b5":[6,0,0,52,1],
+"structlibcamera_1_1IPABuffer.html#a256847bdaa0df391855638eef7b027b5":[7,0,0,51,1],
+"structlibcamera_1_1IPABuffer.html#a95ec7586dc1c7060228423f182329ca6":[6,0,0,52,0],
+"structlibcamera_1_1IPABuffer.html#a95ec7586dc1c7060228423f182329ca6":[7,0,0,51,0],
+"structlibcamera_1_1IPACameraSensorInfo.html":[6,0,0,53],
+"structlibcamera_1_1IPACameraSensorInfo.html":[7,0,0,52],
+"structlibcamera_1_1IPACameraSensorInfo.html#a011900b9facd39607ad8d2e73cf2ec41":[6,0,0,53,10],
+"structlibcamera_1_1IPACameraSensorInfo.html#a011900b9facd39607ad8d2e73cf2ec41":[7,0,0,52,10],
+"structlibcamera_1_1IPACameraSensorInfo.html#a19967b85dd282779a331c126460d2ce8":[6,0,0,53,7],
+"structlibcamera_1_1IPACameraSensorInfo.html#a19967b85dd282779a331c126460d2ce8":[7,0,0,52,7],
+"structlibcamera_1_1IPACameraSensorInfo.html#a76f7926bb79f7f80781f67367ec4d13d":[6,0,0,53,3],
+"structlibcamera_1_1IPACameraSensorInfo.html#a76f7926bb79f7f80781f67367ec4d13d":[7,0,0,52,3],
+"structlibcamera_1_1IPACameraSensorInfo.html#a9bac676fe3ea200b18d42a3561c8a851":[6,0,0,53,8],
+"structlibcamera_1_1IPACameraSensorInfo.html#a9bac676fe3ea200b18d42a3561c8a851":[7,0,0,52,8],
+"structlibcamera_1_1IPACameraSensorInfo.html#aade1f3bd6e1d04666746d157382d6a23":[6,0,0,53,2],
+"structlibcamera_1_1IPACameraSensorInfo.html#aade1f3bd6e1d04666746d157382d6a23":[7,0,0,52,2],
+"structlibcamera_1_1IPACameraSensorInfo.html#ab0cf3b83926392c91fd167fedd035d89":[6,0,0,53,5],
+"structlibcamera_1_1IPACameraSensorInfo.html#ab0cf3b83926392c91fd167fedd035d89":[7,0,0,52,5],
+"structlibcamera_1_1IPACameraSensorInfo.html#ab9bcb46cefbc066407cc2b452968aeb4":[6,0,0,53,0],
+"structlibcamera_1_1IPACameraSensorInfo.html#ab9bcb46cefbc066407cc2b452968aeb4":[7,0,0,52,0],
+"structlibcamera_1_1IPACameraSensorInfo.html#ad02984d923b166afde48d66e4cec8738":[6,0,0,53,6],
+"structlibcamera_1_1IPACameraSensorInfo.html#ad02984d923b166afde48d66e4cec8738":[7,0,0,52,6],
+"structlibcamera_1_1IPACameraSensorInfo.html#adca663df67aa7c342ae826268ebd3f35":[6,0,0,53,1],
+"structlibcamera_1_1IPACameraSensorInfo.html#adca663df67aa7c342ae826268ebd3f35":[7,0,0,52,1],
+"structlibcamera_1_1IPACameraSensorInfo.html#ae4cde230536546acdd994a9648186222":[6,0,0,53,4],
+"structlibcamera_1_1IPACameraSensorInfo.html#ae4cde230536546acdd994a9648186222":[7,0,0,52,4],
+"structlibcamera_1_1IPACameraSensorInfo.html#afd51f1c6e93cafac4158655f0bfcdb48":[6,0,0,53,9],
+"structlibcamera_1_1IPACameraSensorInfo.html#afd51f1c6e93cafac4158655f0bfcdb48":[7,0,0,52,9],
+"structlibcamera_1_1IPAModuleInfo.html":[6,0,0,58],
+"structlibcamera_1_1IPAModuleInfo.html":[7,0,0,57],
+"structlibcamera_1_1IPAModuleInfo.html#a331a23c0af4e231386774d3669c2ae2b":[6,0,0,58,1],
+"structlibcamera_1_1IPAModuleInfo.html#a331a23c0af4e231386774d3669c2ae2b":[7,0,0,57,1],
+"structlibcamera_1_1IPAModuleInfo.html#a5112863521e069a2cea6ffa86f55cc57":[6,0,0,58,3],
+"structlibcamera_1_1IPAModuleInfo.html#a5112863521e069a2cea6ffa86f55cc57":[7,0,0,57,3],
+"structlibcamera_1_1IPAModuleInfo.html#ac33bfdafdebc4fce25b96a2508a9893e":[6,0,0,58,0],
+"structlibcamera_1_1IPAModuleInfo.html#ac33bfdafdebc4fce25b96a2508a9893e":[7,0,0,57,0],
+"structlibcamera_1_1IPAModuleInfo.html#afa7eac2cdc30d72d5d5002ebdafa44ab":[6,0,0,58,2],
+"structlibcamera_1_1IPAModuleInfo.html#afa7eac2cdc30d72d5d5002ebdafa44ab":[7,0,0,57,2],
+"structlibcamera_1_1IPASettings.html":[6,0,0,60],
+"structlibcamera_1_1IPASettings.html":[7,0,0,59],
+"structlibcamera_1_1IPASettings.html#a00504797aa18b72a4a33d2a3fcf45279":[6,0,0,60,1],
+"structlibcamera_1_1IPASettings.html#a00504797aa18b72a4a33d2a3fcf45279":[7,0,0,59,1],
+"structlibcamera_1_1IPASettings.html#a4a81359d9f743910b187bf90d9b5405d":[6,0,0,60,0],
+"structlibcamera_1_1IPASettings.html#a4a81359d9f743910b187bf90d9b5405d":[7,0,0,59,0],
+"structlibcamera_1_1IPAStream.html":[6,0,0,61],
+"structlibcamera_1_1IPAStream.html":[7,0,0,60],
+"structlibcamera_1_1IPAStream.html#a20526c2857a72c075d7c7529e104ca0d":[6,0,0,61,1],
+"structlibcamera_1_1IPAStream.html#a20526c2857a72c075d7c7529e104ca0d":[7,0,0,60,1],
+"structlibcamera_1_1IPAStream.html#ab8218f8e29722c3c7ec6af0acec81e34":[6,0,0,61,0],
+"structlibcamera_1_1IPAStream.html#ab8218f8e29722c3c7ec6af0acec81e34":[7,0,0,60,0],
+"structlibcamera_1_1IPCMessage_1_1Header.html":[6,0,0,62,0],
+"structlibcamera_1_1IPCMessage_1_1Header.html":[7,0,0,61,0],
+"structlibcamera_1_1IPCMessage_1_1Header.html#a1cabd51c87ac850dfbbf20bc5e2004c3":[6,0,0,62,0,1],
+"structlibcamera_1_1IPCMessage_1_1Header.html#a1cabd51c87ac850dfbbf20bc5e2004c3":[7,0,0,61,0,1],
+"structlibcamera_1_1IPCMessage_1_1Header.html#aa8309b06580e211a38336eec302ef130":[6,0,0,62,0,0],
+"structlibcamera_1_1IPCMessage_1_1Header.html#aa8309b06580e211a38336eec302ef130":[7,0,0,61,0,0],
+"structlibcamera_1_1IPCUnixSocket_1_1Payload.html":[6,0,0,64,0],
+"structlibcamera_1_1IPCUnixSocket_1_1Payload.html":[7,0,0,63,0],
+"structlibcamera_1_1IPCUnixSocket_1_1Payload.html#a8537c2639c9068d1ca6fa313ccee7530":[6,0,0,64,0,1],
+"structlibcamera_1_1IPCUnixSocket_1_1Payload.html#a8537c2639c9068d1ca6fa313ccee7530":[7,0,0,63,0,1],
+"structlibcamera_1_1IPCUnixSocket_1_1Payload.html#ab92d052b3f26d8fe481ad69003820943":[6,0,0,64,0,0],
+"structlibcamera_1_1IPCUnixSocket_1_1Payload.html#ab92d052b3f26d8fe481ad69003820943":[7,0,0,63,0,0],
+"structlibcamera_1_1PixelFormatInfo_1_1Plane.html":[6,0,0,90,0],
+"structlibcamera_1_1PixelFormatInfo_1_1Plane.html":[7,0,0,89,0],
+"structlibcamera_1_1PixelFormatInfo_1_1Plane.html#a718acb445ae5af9825489f728c78db9c":[6,0,0,90,0,1],
+"structlibcamera_1_1PixelFormatInfo_1_1Plane.html#a718acb445ae5af9825489f728c78db9c":[7,0,0,89,0,1],
+"structlibcamera_1_1PixelFormatInfo_1_1Plane.html#adceda8c9551a6d7475a0f1d31be97869":[6,0,0,90,0,0],
+"structlibcamera_1_1PixelFormatInfo_1_1Plane.html#adceda8c9551a6d7475a0f1d31be97869":[7,0,0,89,0,0],
 "structlibcamera_1_1StreamConfiguration.html":[6,0,0,106],
 "structlibcamera_1_1StreamConfiguration.html":[7,0,0,105],
 "structlibcamera_1_1StreamConfiguration.html#a049e84c31d5217705f9253854ac1b0eb":[6,0,0,106,3],
@@ -234,20 +249,5 @@ var NAVTREEINDEX14 =
 "structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinear.html#a3970bbb64e6a7dff9e5adee9bd46ea7f":[6,0,0,1,8,1,2],
 "structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinear.html#a3970bbb64e6a7dff9e5adee9bd46ea7f":[7,0,0,0,9,1,2],
 "structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinear.html#a3b5944d6bc141690c39d89cd8f68b71a":[6,0,0,1,8,1,0],
-"structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinear.html#a3b5944d6bc141690c39d89cd8f68b71a":[7,0,0,0,9,1,0],
-"structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinear.html#ab6f5bdad5b0eadf69672f28a350d4206":[6,0,0,1,8,1,1],
-"structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinear.html#ab6f5bdad5b0eadf69672f28a350d4206":[7,0,0,0,9,1,1],
-"structlibcamera_1_1ipa_1_1FrameContext.html":[6,0,0,1,13],
-"structlibcamera_1_1ipa_1_1FrameContext.html":[7,0,0,0,14],
-"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html":[6,0,0,1,19,0],
-"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html":[7,0,0,0,20,0],
-"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a0c7aa93de0d8b8e8ae207541f5191cbd":[6,0,0,1,19,0,1],
-"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a0c7aa93de0d8b8e8ae207541f5191cbd":[7,0,0,0,20,0,1],
-"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a26b6eb0a059919e60d67bd0472a55fe5":[6,0,0,1,19,0,5],
-"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a26b6eb0a059919e60d67bd0472a55fe5":[7,0,0,0,20,0,5],
-"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a29d5f017b92bc1df8ad0621da6665d82":[6,0,0,1,19,0,0],
-"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a29d5f017b92bc1df8ad0621da6665d82":[7,0,0,0,20,0,0],
-"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a2e6f3f1605126799b3ce0fc21afd6e2a":[6,0,0,1,19,0,4],
-"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a2e6f3f1605126799b3ce0fc21afd6e2a":[7,0,0,0,20,0,4],
-"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a331b6f919b1ab5f928264cc026ae8791":[6,0,0,1,19,0,2]
+"structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinear.html#a3b5944d6bc141690c39d89cd8f68b71a":[7,0,0,0,9,1,0]
 };
