@@ -1,5 +1,20 @@
 var NAVTREEINDEX15 =
 {
+"structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinear.html#ab6f5bdad5b0eadf69672f28a350d4206":[6,0,0,1,8,1,1],
+"structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinear.html#ab6f5bdad5b0eadf69672f28a350d4206":[7,0,0,0,9,1,1],
+"structlibcamera_1_1ipa_1_1FrameContext.html":[6,0,0,1,13],
+"structlibcamera_1_1ipa_1_1FrameContext.html":[7,0,0,0,14],
+"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html":[6,0,0,1,19,0],
+"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html":[7,0,0,0,20,0],
+"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a0c7aa93de0d8b8e8ae207541f5191cbd":[6,0,0,1,19,0,1],
+"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a0c7aa93de0d8b8e8ae207541f5191cbd":[7,0,0,0,20,0,1],
+"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a26b6eb0a059919e60d67bd0472a55fe5":[6,0,0,1,19,0,5],
+"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a26b6eb0a059919e60d67bd0472a55fe5":[7,0,0,0,20,0,5],
+"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a29d5f017b92bc1df8ad0621da6665d82":[6,0,0,1,19,0,0],
+"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a29d5f017b92bc1df8ad0621da6665d82":[7,0,0,0,20,0,0],
+"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a2e6f3f1605126799b3ce0fc21afd6e2a":[6,0,0,1,19,0,4],
+"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a2e6f3f1605126799b3ce0fc21afd6e2a":[7,0,0,0,20,0,4],
+"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a331b6f919b1ab5f928264cc026ae8791":[6,0,0,1,19,0,2],
 "structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a331b6f919b1ab5f928264cc026ae8791":[7,0,0,0,20,0,2],
 "structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a5f346ae3772a018ff2cc79393b6523fc":[6,0,0,1,19,0,3],
 "structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a5f346ae3772a018ff2cc79393b6523fc":[7,0,0,0,20,0,3],
@@ -52,52 +67,52 @@ var NAVTREEINDEX15 =
 "structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator.html#ab1e6f5cca85d97dee2be4a951128f4ef":[7,0,0,0,0,0,0,0],
 "structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator.html#acd5adc623ea0dfda4d96fa212dd28e3a":[7,0,0,0,0,0,0,1],
 "structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator.html#af7531392760fc28dfc4dd4f10e3fdd9d":[7,0,0,0,0,0,0,2],
-"structlibcamera_1_1ipa__control__info__entry.html":[6,0,0,48],
-"structlibcamera_1_1ipa__control__info__entry.html":[7,0,0,47],
-"structlibcamera_1_1ipa__control__info__entry.html#a33abcc499d767a96b05b65c7a7117623":[6,0,0,48,0],
-"structlibcamera_1_1ipa__control__info__entry.html#a33abcc499d767a96b05b65c7a7117623":[7,0,0,47,0],
-"structlibcamera_1_1ipa__control__info__entry.html#a3ca9348b78d59bcb904e149b77820c1a":[6,0,0,48,3],
-"structlibcamera_1_1ipa__control__info__entry.html#a3ca9348b78d59bcb904e149b77820c1a":[7,0,0,47,3],
-"structlibcamera_1_1ipa__control__info__entry.html#a403310b4b798fbcfb73d98982968277b":[6,0,0,48,4],
-"structlibcamera_1_1ipa__control__info__entry.html#a403310b4b798fbcfb73d98982968277b":[7,0,0,47,4],
-"structlibcamera_1_1ipa__control__info__entry.html#a4ecef8de0f7141548b7f966dc0cc2d6f":[6,0,0,48,1],
-"structlibcamera_1_1ipa__control__info__entry.html#a4ecef8de0f7141548b7f966dc0cc2d6f":[7,0,0,47,1],
-"structlibcamera_1_1ipa__control__info__entry.html#a7687c9c06e96be193433f8fb84f513a6":[6,0,0,48,2],
-"structlibcamera_1_1ipa__control__info__entry.html#a7687c9c06e96be193433f8fb84f513a6":[7,0,0,47,2],
-"structlibcamera_1_1ipa__control__value__entry.html":[6,0,0,49],
-"structlibcamera_1_1ipa__control__value__entry.html":[7,0,0,48],
-"structlibcamera_1_1ipa__control__value__entry.html#a753148d23811023e2b90e900cccc58cd":[6,0,0,49,4],
-"structlibcamera_1_1ipa__control__value__entry.html#a753148d23811023e2b90e900cccc58cd":[7,0,0,48,4],
-"structlibcamera_1_1ipa__control__value__entry.html#a774a2ecdfe8fa4cdb15f790145bec941":[6,0,0,49,5],
-"structlibcamera_1_1ipa__control__value__entry.html#a774a2ecdfe8fa4cdb15f790145bec941":[7,0,0,48,5],
-"structlibcamera_1_1ipa__control__value__entry.html#a844de12400cc1be140358d5f60186185":[6,0,0,49,0],
-"structlibcamera_1_1ipa__control__value__entry.html#a844de12400cc1be140358d5f60186185":[7,0,0,48,0],
-"structlibcamera_1_1ipa__control__value__entry.html#a9b4078d231f70baef2cc281b71f86093":[6,0,0,49,2],
-"structlibcamera_1_1ipa__control__value__entry.html#a9b4078d231f70baef2cc281b71f86093":[7,0,0,48,2],
-"structlibcamera_1_1ipa__control__value__entry.html#ac54476dbc956052a7b9c5696775ab2cd":[6,0,0,49,1],
-"structlibcamera_1_1ipa__control__value__entry.html#ac54476dbc956052a7b9c5696775ab2cd":[7,0,0,48,1],
-"structlibcamera_1_1ipa__control__value__entry.html#ae3d8c5b415250572674642007afa09e4":[6,0,0,49,3],
-"structlibcamera_1_1ipa__control__value__entry.html#ae3d8c5b415250572674642007afa09e4":[7,0,0,48,3],
-"structlibcamera_1_1ipa__controls__header.html":[6,0,0,50],
-"structlibcamera_1_1ipa__controls__header.html":[7,0,0,49],
-"structlibcamera_1_1ipa__controls__header.html#a3a765c275ff9ca1fbeb6c30710991735":[6,0,0,50,6],
-"structlibcamera_1_1ipa__controls__header.html#a3a765c275ff9ca1fbeb6c30710991735":[7,0,0,49,6],
-"structlibcamera_1_1ipa__controls__header.html#a50ee3982972502f935ce3e3b79990567":[6,0,0,50,3],
-"structlibcamera_1_1ipa__controls__header.html#a50ee3982972502f935ce3e3b79990567":[7,0,0,49,3],
-"structlibcamera_1_1ipa__controls__header.html#a6d03513b3c1f04f287de210fb43aa3e2":[6,0,0,50,1],
-"structlibcamera_1_1ipa__controls__header.html#a6d03513b3c1f04f287de210fb43aa3e2":[7,0,0,49,1],
-"structlibcamera_1_1ipa__controls__header.html#a70508610b6dade518629ad83084aa8ce":[6,0,0,50,5],
-"structlibcamera_1_1ipa__controls__header.html#a70508610b6dade518629ad83084aa8ce":[7,0,0,49,5],
-"structlibcamera_1_1ipa__controls__header.html#a81b5c98068052c2cbae3d15e99f75397":[6,0,0,50,0],
-"structlibcamera_1_1ipa__controls__header.html#a81b5c98068052c2cbae3d15e99f75397":[7,0,0,49,0],
-"structlibcamera_1_1ipa__controls__header.html#aaac149bc6a0d18f3a3a6af0267f343f9":[6,0,0,50,2],
-"structlibcamera_1_1ipa__controls__header.html#aaac149bc6a0d18f3a3a6af0267f343f9":[7,0,0,49,2],
-"structlibcamera_1_1ipa__controls__header.html#aae7b6e93ea8232cada633db48383f787":[6,0,0,50,4],
-"structlibcamera_1_1ipa__controls__header.html#aae7b6e93ea8232cada633db48383f787":[7,0,0,49,4],
+"structlibcamera_1_1ipa__control__info__entry.html":[6,0,0,49],
+"structlibcamera_1_1ipa__control__info__entry.html":[7,0,0,48],
+"structlibcamera_1_1ipa__control__info__entry.html#a33abcc499d767a96b05b65c7a7117623":[6,0,0,49,0],
+"structlibcamera_1_1ipa__control__info__entry.html#a33abcc499d767a96b05b65c7a7117623":[7,0,0,48,0],
+"structlibcamera_1_1ipa__control__info__entry.html#a3ca9348b78d59bcb904e149b77820c1a":[6,0,0,49,3],
+"structlibcamera_1_1ipa__control__info__entry.html#a3ca9348b78d59bcb904e149b77820c1a":[7,0,0,48,3],
+"structlibcamera_1_1ipa__control__info__entry.html#a403310b4b798fbcfb73d98982968277b":[6,0,0,49,4],
+"structlibcamera_1_1ipa__control__info__entry.html#a403310b4b798fbcfb73d98982968277b":[7,0,0,48,4],
+"structlibcamera_1_1ipa__control__info__entry.html#a4ecef8de0f7141548b7f966dc0cc2d6f":[6,0,0,49,1],
+"structlibcamera_1_1ipa__control__info__entry.html#a4ecef8de0f7141548b7f966dc0cc2d6f":[7,0,0,48,1],
+"structlibcamera_1_1ipa__control__info__entry.html#a7687c9c06e96be193433f8fb84f513a6":[6,0,0,49,2],
+"structlibcamera_1_1ipa__control__info__entry.html#a7687c9c06e96be193433f8fb84f513a6":[7,0,0,48,2],
+"structlibcamera_1_1ipa__control__value__entry.html":[6,0,0,50],
+"structlibcamera_1_1ipa__control__value__entry.html":[7,0,0,49],
+"structlibcamera_1_1ipa__control__value__entry.html#a753148d23811023e2b90e900cccc58cd":[6,0,0,50,4],
+"structlibcamera_1_1ipa__control__value__entry.html#a753148d23811023e2b90e900cccc58cd":[7,0,0,49,4],
+"structlibcamera_1_1ipa__control__value__entry.html#a774a2ecdfe8fa4cdb15f790145bec941":[6,0,0,50,5],
+"structlibcamera_1_1ipa__control__value__entry.html#a774a2ecdfe8fa4cdb15f790145bec941":[7,0,0,49,5],
+"structlibcamera_1_1ipa__control__value__entry.html#a844de12400cc1be140358d5f60186185":[6,0,0,50,0],
+"structlibcamera_1_1ipa__control__value__entry.html#a844de12400cc1be140358d5f60186185":[7,0,0,49,0],
+"structlibcamera_1_1ipa__control__value__entry.html#a9b4078d231f70baef2cc281b71f86093":[6,0,0,50,2],
+"structlibcamera_1_1ipa__control__value__entry.html#a9b4078d231f70baef2cc281b71f86093":[7,0,0,49,2],
+"structlibcamera_1_1ipa__control__value__entry.html#ac54476dbc956052a7b9c5696775ab2cd":[6,0,0,50,1],
+"structlibcamera_1_1ipa__control__value__entry.html#ac54476dbc956052a7b9c5696775ab2cd":[7,0,0,49,1],
+"structlibcamera_1_1ipa__control__value__entry.html#ae3d8c5b415250572674642007afa09e4":[6,0,0,50,3],
+"structlibcamera_1_1ipa__control__value__entry.html#ae3d8c5b415250572674642007afa09e4":[7,0,0,49,3],
+"structlibcamera_1_1ipa__controls__header.html":[6,0,0,51],
+"structlibcamera_1_1ipa__controls__header.html":[7,0,0,50],
+"structlibcamera_1_1ipa__controls__header.html#a3a765c275ff9ca1fbeb6c30710991735":[6,0,0,51,6],
+"structlibcamera_1_1ipa__controls__header.html#a3a765c275ff9ca1fbeb6c30710991735":[7,0,0,50,6],
+"structlibcamera_1_1ipa__controls__header.html#a50ee3982972502f935ce3e3b79990567":[6,0,0,51,3],
+"structlibcamera_1_1ipa__controls__header.html#a50ee3982972502f935ce3e3b79990567":[7,0,0,50,3],
+"structlibcamera_1_1ipa__controls__header.html#a6d03513b3c1f04f287de210fb43aa3e2":[6,0,0,51,1],
+"structlibcamera_1_1ipa__controls__header.html#a6d03513b3c1f04f287de210fb43aa3e2":[7,0,0,50,1],
+"structlibcamera_1_1ipa__controls__header.html#a70508610b6dade518629ad83084aa8ce":[6,0,0,51,5],
+"structlibcamera_1_1ipa__controls__header.html#a70508610b6dade518629ad83084aa8ce":[7,0,0,50,5],
+"structlibcamera_1_1ipa__controls__header.html#a81b5c98068052c2cbae3d15e99f75397":[6,0,0,51,0],
+"structlibcamera_1_1ipa__controls__header.html#a81b5c98068052c2cbae3d15e99f75397":[7,0,0,50,0],
+"structlibcamera_1_1ipa__controls__header.html#aaac149bc6a0d18f3a3a6af0267f343f9":[6,0,0,51,2],
+"structlibcamera_1_1ipa__controls__header.html#aaac149bc6a0d18f3a3a6af0267f343f9":[7,0,0,50,2],
+"structlibcamera_1_1ipa__controls__header.html#aae7b6e93ea8232cada633db48383f787":[6,0,0,51,4],
+"structlibcamera_1_1ipa__controls__header.html#aae7b6e93ea8232cada633db48383f787":[7,0,0,50,4],
 "swisp__stats_8h_source.html":[8,0,1,0,1,1,2],
 "swstats__cpu_8h_source.html":[8,0,2,1,0,3],
-"sysfs_8h.html":[8,0,1,0,1,36],
-"sysfs_8h_source.html":[8,0,1,0,1,36],
+"sysfs_8h.html":[8,0,1,0,1,37],
+"sysfs_8h_source.html":[8,0,1,0,1,37],
 "thread-safety.html":[1],
 "thread.html":[2],
 "thread.html#thread-objects":[2,0],
@@ -116,17 +131,17 @@ var NAVTREEINDEX15 =
 "unique__fd_8h_source.html":[8,0,1,0,0,20],
 "utils_8h.html":[8,0,1,0,0,21],
 "utils_8h_source.html":[8,0,1,0,0,21],
-"v4l2__device_8h.html":[8,0,1,0,1,37],
-"v4l2__device_8h_source.html":[8,0,1,0,1,37],
-"v4l2__pixelformat_8h.html":[8,0,1,0,1,38],
-"v4l2__pixelformat_8h_source.html":[8,0,1,0,1,38],
-"v4l2__subdevice_8h.html":[8,0,1,0,1,39],
-"v4l2__subdevice_8h_source.html":[8,0,1,0,1,39],
-"v4l2__videodevice_8h.html":[8,0,1,0,1,40],
-"v4l2__videodevice_8h_source.html":[8,0,1,0,1,40],
-"vector_8h.html":[8,0,1,0,1,41],
-"vector_8h_source.html":[8,0,1,0,1,41],
+"v4l2__device_8h.html":[8,0,1,0,1,38],
+"v4l2__device_8h_source.html":[8,0,1,0,1,38],
+"v4l2__pixelformat_8h.html":[8,0,1,0,1,39],
+"v4l2__pixelformat_8h_source.html":[8,0,1,0,1,39],
+"v4l2__subdevice_8h.html":[8,0,1,0,1,40],
+"v4l2__subdevice_8h_source.html":[8,0,1,0,1,40],
+"v4l2__videodevice_8h.html":[8,0,1,0,1,41],
+"v4l2__videodevice_8h_source.html":[8,0,1,0,1,41],
+"vector_8h.html":[8,0,1,0,1,42],
+"vector_8h_source.html":[8,0,1,0,1,42],
 "version_8h_source.html":[8,0,0,0,0,5],
-"yaml__parser_8h.html":[8,0,1,0,1,42],
-"yaml__parser_8h_source.html":[8,0,1,0,1,42]
+"yaml__parser_8h.html":[8,0,1,0,1,43],
+"yaml__parser_8h_source.html":[8,0,1,0,1,43]
 };
